--- title: anabel.sections summary: High-level section modeling API. template: pdoc.html ...

# Section Modeling

High-level section modeling API.

## Functions

`def Composite_Section(Y, DY, DZ, quad, y_shift=0.0, mat=None)`
`def I_Sect(b, d, alpha, beta, quad, yref=0.0, MatData=None)`
`def TC_Sect(d, bf, tw, quad, yref=0.0, tf=None, ymf=None, MatData=None, **kwds)`
`def T_Sect(d, quad, b=None, bf=None, tf=None, tw=None, alpha=None, beta=None, yref=0.0, MatData=None)`
`def W_Sect(b, d, alpha, beta, quadf, quadw, yref=0.0, MatData=None)`
`def ei(y, epsa, kappa)`
`def epsi(y, epsa, kappa)`
`def load_aisc(SectionName, props='')`

  Load cross section properties from AISC database.

  props: A list of AISC properties, or one of the following: - ‘simple’: `A`, `Ix`, `Zx`

`def section2d(yi, dA, nIP, mat, **kwds)`

  Generate a section response function

  ## Studies

## Classes

`class Rectangle (b, d, quad=None, yref=0.0, mat=None, **kwds)`

  Rectangular cross section

  ### Ancestors

  - Section
`class Section`

  ### Subclasses

  - Rectangle
  - Tee

  ### Methods

  `def assemble(self)`
`class Tee (d=None, quad=None, b=None, bf=None, tf=None, tw=None, alpha=None, beta=None, yref=0.0, mat=None)`

  ### Ancestors

  - Section